@@ -4,7 +4,10 @@ from random import randint,choice
 from os import system,urandom
 from termcolor import colored
 import f61d.LOGO as LOGO
+from f61d.__version__ import *
 
+
+__version__ == __VERSION__
 print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
 print(colored("Welcome to F61D. Use Help() for help.",'green'))
 
@@ -17,6 +20,8 @@ help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n                  sha256(XXXX + abcdef) = aaabbb...'
 help_cont[6] = 'Nim      : An interesting turtle game.'
 help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
+help_cont[8] - 'yinyang  : Draw the TaiJi.'
+
 
 def Help(page=1,lines = 5):
     maxPage = int((0.5+len(help_cont))/lines)+1
@@ -132,6 +137,11 @@ def prove(cont):
 def getLogo():
     print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
     
+
+def yinyang():
+    import f61d.yinyang
+    f61d.yinyang.main()
+    
     
 def main():
     help()
